about summary refs log tree commit diff
path: root/absl/flags/usage_config.cc
diff options
context:
space:
mode:
authorPavel Samolysov <samolisov@gmail.com>2020-03-09T18·37+0300
committerGitHub <noreply@github.com>2020-03-09T18·37-0400
commit238b9a59c874f8271ce781d9d05d81eb61728132 (patch)
tree4a8b07228b32fb96a70738112db6f8adff7cbe81 /absl/flags/usage_config.cc
parent417ea99cbac80c85be9f52c8b482f15d47bee93e (diff)
Skip the .exe suffix in the helpshort filter on Windows (#629)
On Windows, the `flags_internal::ShortProgramInvocationName()`
function usually returns the program name with '.exe' (if the
extension is present in the command line during the program startup).
This fact breaks the checks in the `ContainsHelpshortFlags` filter:
obviously, module names have no .exe in them. Therefore, no defined flags
are shown when the program runs with the --help flag. The program name
should be used in filter without this extension even though it is present.

The unit test has also been updated.

Signed-off-by: Pavel Samolysov <samolisov@gmail.com>
Diffstat (limited to 'absl/flags/usage_config.cc')
-rw-r--r--absl/flags/usage_config.cc11
1 files changed, 8 insertions, 3 deletions
diff --git a/absl/flags/usage_config.cc b/absl/flags/usage_config.cc
index 2d837ec590..0d21bce6a9 100644
--- a/absl/flags/usage_config.cc
+++ b/absl/flags/usage_config.cc
@@ -50,10 +50,15 @@ namespace {
 bool ContainsHelpshortFlags(absl::string_view filename) {
   // By default we only want flags in binary's main. We expect the main
   // routine to reside in <program>.cc or <program>-main.cc or
   // <program>_main.cc, where the <program> is the name of the binary.
   auto suffix = flags_internal::Basename(filename);
-  if (!absl::ConsumePrefix(&suffix,
-                           flags_internal::ShortProgramInvocationName()))
+  auto program_name = flags_internal::ShortProgramInvocationName();
+  absl::string_view program_name_ref = program_name;
+#if defined(_WIN32)
+  absl::ConsumeSuffix(&program_name_ref, ".exe");
+#endif
+  if (!absl::ConsumePrefix(&suffix, program_name_ref))
     return false;
   return absl::StartsWith(suffix, ".") || absl::StartsWith(suffix, "-main.") ||
          absl::StartsWith(suffix, "_main.");
@@ -50,10 +50,15 @@ namespace {
   // By default we only want flags in binary's main. We expect the main
   // routine to reside in <program>.cc or <program>-main.cc or
-  // <program>_main.cc, where the <program> is the name of the binary.
+  // <program>_main.cc, where the <program> is the name of the binary
+  // (without .exe on Windows).
   auto suffix = flags_internal::Basename(filename);